{% templatetag openblock %} extends "bigbuild/base.html" {% templatetag closeblock %}
{% templatetag openblock %} load compress greeking_tags bigbuild_tags {% templatetag closeblock %}

{% templatetag openblock %} block extra-css {% templatetag closeblock %}
    {% if sans %}<link rel="stylesheet" type="text/css" href="http://d1qqc1e9kvmdh8.cloudfront.net/css/ngux-sans-0.5.3.min.css" />{% endif %}
    {% if dark %}<link rel="stylesheet" type="text/css" href="http://d1qqc1e9kvmdh8.cloudfront.net/css/ngux-dark-0.5.3.min.css" />{% endif %}
    {% templatetag openblock %} compress css inline {% templatetag closeblock %}
    <link rel="stylesheet" href="{% templatetag openvariable %} STATIC_URL {% templatetag closevariable %}style.css">
    {% templatetag openblock %} endcompress {% templatetag closeblock %}
{% templatetag openblock %} endblock {% templatetag closeblock %}

{% templatetag openblock %} block container {% templatetag closeblock %}
<article class="container">
    <header class="center">
        {% templatetag openblock %} include 'ngux-tophat/share-buttons.html' {% templatetag closeblock %}
        <h1>{% templatetag openvariable %} object.headline {% templatetag closevariable %}</h1>
        <p class="description">{% templatetag openvariable %} object.description|safe {% templatetag closevariable %}</p>
        <p class="byline">
            By <span class="author">{% templatetag openvariable %} object.byline|safe {% templatetag closevariable %}</span>
        </p>
        <p class="dateline">
            <time datetime="{% templatetag openvariable %} object.pub_date|date:"Y-m-d" {% templatetag closevariable %}" pubdate>
                {% templatetag openvariable %} object.pub_date|date:"N j, Y" {% templatetag closevariable %}
            </time>
        </p>
    </header>
    <section name="graphic" class="graphic"></section>
    <section name="credits">
        {% templatetag openblock %} if object.extra.sources {% templatetag closeblock %}
            <p class="sources">Sources: {% templatetag openvariable %} object.extra.sources|safe {% templatetag closevariable %}</p>
        {% templatetag openblock %} endif {% templatetag closeblock %}
        {% templatetag openblock %} if object.extra.credits {% templatetag closeblock %}
            <p class="credits">Credits: {% templatetag openvariable %} object.extra.credits|safe {% templatetag closevariable %}</p>
        {% templatetag openblock %} endif {% templatetag closeblock %}
    </section>
</article>
{% templatetag openblock %} endblock {% templatetag closeblock %}

{% templatetag openblock %} block body-bottom {% templatetag closeblock %}
{% templatetag openblock %} compress js inline {% templatetag closeblock %}
<script type="text/javascript" src="{% templatetag openvariable %} STATIC_URL {% templatetag closevariable %}app.js"></script>
{% templatetag openblock %} endcompress {% templatetag closeblock %}
<script type="text/javascript">
$(function () {
    app.boot();
});
</script>
{% templatetag openblock %} endblock {% templatetag closeblock %}
