<!DOCTYPE html>
<html lang="{% block lang %}en{% endblock %}" {% block extra-html %}{% endblock %}>
<head>
    {% block chartbeat-top %}<script type='text/javascript'>var _sf_startpt=(new Date()).getTime()</script>{% endblock %}

    <!-- METADATA -->
    <title>{% block title %}Los Angeles Times{% endblock %}</title>
    {% block meta %}
        <meta charset="utf-8" />
        <meta name="description" content="{% block description %}{% endblock %}" />
        <meta name="keywords" content="{% block keywords %}data desk, los angeles times, latimes, l.a. times{% endblock %}" />
        {% block viewport %}<meta name="viewport" content="width=device-width, initial-scale=1.0">{% endblock %}
        <link rel="shortcut icon" type="image/x-icon" href="//cookbook.latimes.com/img/favicon.ico">
        <link rel="publisher" href="//plus.google.com/u/0/112727226361732924638" />
        <meta name="google-site-verification" content="a9pAUAoFTyj7Nut3H5OiQ-fUyyqdwdVT7VcFGICrpTo" />
        {% block extra-meta %}{% endblock %}
    {% endblock %}

    <!-- CSS -->
    {% block css %}
    <link rel="stylesheet" type="text/css" href="//cookbook.latimes.com/bootstrap/2.3.2/css/bootstrap.min.css" />
    <link rel="stylesheet" type="text/css" href="//cookbook.latimes.com/css/ngux-tophat-1.0.9.min.css" />
    <link rel="stylesheet" type="text/css" href="//cookbook.latimes.com/bootstrap/2.3.2/css/bootstrap-responsive.min.css" />
    <link rel="stylesheet" type="text/css" href="//cookbook.latimes.com/css/ngux-tophat-responsive-1.0.9.min.css" />
    {% endblock %}

    {% block extra-css %}{% endblock %}

    <!-- JAVASCRIPT -->
    {% block js %}
    {% block html5shiv %}
    <!--[if lt IE 9]>
          <script type="text/javascript" src="//cookbook.latimes.com/js/html5shiv.js"></script>
     <![endif]-->
    {% endblock %}
    {% block jquery %}<script type="text/javascript" src="//cookbook.latimes.com/js/jquery-1.12.4/jquery.min.js"></script>{% endblock %}
    {% block bootstrap %}<script type="text/javascript" src="//cookbook.latimes.com/bootstrap/2.3.2/js/bootstrap.min.js"></script>{% endblock %}
    {% block underscore %}<script src="//cookbook.latimes.com/js/underscore-1.8.3-min.js" type="text/javascript"></script>{% endblock %}
    {% block gigya %}<script type="text/javascript" src="//cdn.gigya.com/js/socialize.js?apiKey=2_COh26GgfZDptreu0iQ9aknzT_Ig861qYxOHZVxizrZMTn81vygTB-ptN33wgCtrj"></script>{% endblock %}
    {% block tophat-js %}<script type="text/javascript" src="//cookbook.latimes.com/js/ngux-tophat-1.0.9.min.js"></script>{% endblock %}
    <!--[if lte IE 7]><script type="text/javascript" src="//cookbook.latimes.com/js/icons-ie7.js"></script><![endif]-->
    {% block ad-js %}<script type="text/javascript" src="//cookbook.latimes.com/js/ngux-ads-2.4.1.min.js"></script>{% endblock %}
    {% endblock %}

    {% block extra-js %}{% endblock %}
    {% block extra-rss %}{% endblock %}
    {% block extra-head %}{% endblock %}
</head>
<body {% block extra-body %}data-ad-path="4011/trb.latimes{% block ad-path %}/news/datadesk{% endblock %}" data-ad-ptype="{% block ad-ptype %}s{% endblock %}" data-ad-iframe-url="{% block ad-iframe %}/static/ngux-tophat-ad-iframe.html{% endblock %}"{% endblock %} >
    <!-- NAV -->
    {% block nav %}
    <nav title="Navigation">
        {% include "ngux-tophat/nav/default.html" %}
    </nav>
    {% endblock %}

    {% block container %}
    <!-- CONTENT GOES HERE -->
    <div class="container" id="container">
        {% block banner-ad %}
            {%include "ngux-tophat/ads/banner.html" %}
        {% endblock %}
        <article>
        {% block content %}
        {% endblock %}
        </article>
    </div>
    {% endblock %}

    {% block stats %}

        <!-- Google Analytics code -->
        <script type="text/javascript">
              (function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
              (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
              m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
              })(window,document,'script','//www.google-analytics.com/analytics.js','ga');

              ga('create', '{% block google-analytics-id %}UA-22575524-1{% endblock %}', 'latimes.com');
              ga('send', 'pageview');
        </script>

        {% block omniture %}
        <script type="text/javascript">
            ((((window.trb || (window.trb = {})).data || (trb.data = {})).metrics || (trb.data.metrics = {})).thirdparty = {
                // Page naming convention:
                //  <site-slug>:<app-slug>:<path>:<datadesk-slug>-<page-slug>:<content-type>.
                // Example:
                //  lat:projects.latimes.com:local:data-pat-tillman:individualarticle.
                //  (Don't miss the period at the end.)
                pageName: 'lat:{% block omniture-pageName %}{% endblock %}.',
                channel: '{% block omniture-channel %}local{% endblock %}', // Path
                server: '{% block omniture-server %}www.latimes.com{% endblock %}', // Full domain
                hier1: 'latimes:{% block omniture-full-tribune-path %}local{% endblock %}', // Path (with latimes prefix)
                hier2: '{% block omniture-full-latimes-path %}local{% endblock %}', // Path (again)
                prop1: 'D=pageName',
                prop2: '{% block omniture-base-latimes-path %}local{% endblock %}', // Path (again!)
                prop38: '{% block omniture-contenttype %}individualarticle{% endblock %}', // Content type
                eVar1: {% block omniture-url %}window.location.href{% endblock %}, // This URL
                eVar2: {% block omniture-referring-url %}document.referrer{% endblock %}, // The referring URL
                prop57: 'D=c38',
                eVar20: 'latimes',
                eVar21: 'D=c38',
                eVar34: 'D=ch',
                eVar35: 'D=pageName',
                events: ''
            });
        </script>
        <script src="//www.latimes.com/thirdpartyservice?disablenav=true"></script>
        {% endblock %}

    {% endblock %}

    {% block footer %}
    <footer title="Footer">
        {% include "ngux-tophat/footer/default.html" %}
    </footer>
    {% endblock %}

    {% block body-bottom %}{% endblock %}

    {% block chartbeat-bottom %}
    <script type="text/javascript">
    var _sf_async_config={};
        /** CONFIGURATION START **/
        _sf_async_config.uid = {%block chartbeat-uid %}3908{% endblock %};
        _sf_async_config.domain = '{% block chartbeat-domain %}www.latimes.com{% endblock %}';
        _sf_async_config.useCanonical = true;
        _sf_async_config.sections = '{% block chartbeat-sections %}{% endblock %}';
        _sf_async_config.authors = '{% block chartbeat-authors %}Data Desk{% endblock %}';
        /** CONFIGURATION END **/
        (function(){
          function loadChartbeat() {
            window._sf_endpt=(new Date()).getTime();
            var e = document.createElement('script');
            e.setAttribute('language', 'javascript');
            e.setAttribute('type', 'text/javascript');
            e.setAttribute('src', '//static.chartbeat.com/js/chartbeat.js');
            document.body.appendChild(e);
          }
          var oldonload = window.onload;
          window.onload = (typeof window.onload != 'function') ?
             loadChartbeat : function() { oldonload(); loadChartbeat(); };
        })();
    </script>
    {% endblock %}

</body>
<!--Good with data?-->
<!--Tired of grinding on the same old apps?-->
<!--Want to use your skills in defense of truth, justice and the American way?-->
<!--Email datadesk@latimes.com and let us know you're out there.-->
</html>
