<aside title="Advertisement" class="cube-ad">
    <div class="tophat-cube" id='div-gpt-ad-240326138443017849-1'>
        <div class="advert" data-ad-type="cube"></div>
        <span class="tophat-ad-label">ADVERTISEMENT</span>
    </div>
</aside>
