<div class="row-fluid" id="contentBottom">
	    <div class="span8">
	        <h2 style="font-size:25px; margin-bottom:10px;" class="facebook_comments">{% if object.facebook_share_question %}{{ object.facebook_share_question }}{% else %}Readers: What&rsquo;s your take? Share it here.{% endif %}</h2>
	        <div id="fb-root"></div>
	        <script type="text/javascript" src="//connect.facebook.net/en_US/all.js#xfbml=1"></script>
	        <fb:comments href="//www.latimes.com{{ object.get_absolute_url }}" order_by="reverse_time"></fb:comments>
	    </div>
    <div id="rail" class="span4">
        {% include "tophat/ads/cube.html" %}
    </div>
</div>
