<aside title="Advertisement" class="banner-ad">
    <div class="tophat-banner-container">
        <div class="tophat-banner">
            <div class="advert"></div>
            <span class="tophat-ad-label">ADVERTISEMENT</span>
        </div>
    </div>
</aside>
