{% extends "ngux-tophat/nav/default.html" %}

{% block nav-logo %}
    <a id="tophat-logo" class="hoy" href="//www.hoylosangeles.com/"></a>
{% endblock %}

{% block nav-links %}
    <div class="tophat-links">
        <ul>
            <li>
                <a href="//www.hoylosangeles.com/especiales/ciudadaniahoy/">Ciudadanía Hoy</a>
            </li>
            <li>
                <a href="//www.hoylosangeles.com/noticias/local/educacion/">Educación</a>
            </li>
            <li>
                <a href="//www.hoylosangeles.com/espectaculos/">Espectáculos</a>
            </li>
            <li>
                <a href="//www.hoylosangeles.com/deportes/">Deportes</a>
            </li>
            <li>
                <a href="//www.hoylosangeles.com/noticias/">Noticias</a>
            </li>
            <li>
                <a href="//www.hoylosangeles.com/latimesespanol/">LA Times Español</a>
            </li>
            <li>
                <a href="//www.hoylosangeles.com/multimedia/hoytv/">Hoy TV</a>
            </li>
            <li>
                <a href="//www.hoylosangeles.com/datablog/">Datos y Mapas</a>
            </li>
        </ul>
    </div>
{% endblock %}
