{% extends 'base.html' %}

{% block title %}Server Error - {{ block.super }}{% endblock %}
{% block omniture-pageName %}{{ block.super }}page not found:page not found{% endblock %}
{% block omniture-contenttype %}page not found{% endblock %}
{% block omniture-channel %}page not found{% endblock %}
{% block omniture-full-tribune-path %}page not found{% endblock %}
{% block omniture-full-latimes-path %}page not found{% endblock %}
{% block omniture-base-latimes-path %}page not found{% endblock %}

{% block content %}
<div style="margin-left:12px;">
    <h1 class="detail-title pad10vert">We're sorry.</h1>
    <div style="font-size:16px">
        <p>There was a mistake loading your page.</p>
        <p style="margin-top:12px;">
            The site administrator has been notified about the problem. 
        </p>
        <p style="margin-top:12px;">
            Please wait a few minutes and try again.
        </p>
    </div>
</div>
{% endblock %}
