<link rel="stylesheet"
    href="//d1qqc1e9kvmdh8.cloudfront.net/js/leaflet.label-0.2.3/leaflet.label.css">
<script
    type="text/javascript"
    src="//d1qqc1e9kvmdh8.cloudfront.net/js/leaflet.label-0.2.3/leaflet.label.src.js"></script>
<script
    type="text/javascript"
    src="//d1qqc1e9kvmdh8.cloudfront.net/js/L.Control.Locate.min.js" type="text/javascript"></script>

<style type="text/css">
    {% include "ngux-tophat/maps/custom-tools.css" %}
</style>

<script type="text/template" id="legend-template-swatch">
    {% include "ngux-tophat/maps/legend-swatch.jst" %}
</script>

<script type="text/template" id="legend-template-scale">
    {% include "ngux-tophat/maps/legend-scale.jst" %}
</script>

<script type="text/javascript">
    {% include "ngux-tophat/maps/corner-overlay.js" %}
    {% include "ngux-tophat/maps/feature-box.js" %}
    {% include "ngux-tophat/maps/legend.js" %}
    {% include "ngux-tophat/maps/modal.js" %}
    {% include "ngux-tophat/maps/defaults.js" %}
    {% include "ngux-tophat/maps/presets.js" %}
</script>
