{% extends "ngux-tophat/footer/default.html" %}

{% block lang %}es{% endblock %}

{% block footer-links %}
    <div id="tos" class="hoy">
        <a href="//www.tronc.com/terminos-de-servicio-principales/">Condiciones</a> |
        <a href="//www.tronc.com/politica-de-privacidad/">Privacidad</a> |
        <a href="//www.hoylosangeles.com/hoyla-adv-informacin-de-nuestros-anuncios-20150416-story.html"><span class="hidden-phone">Información de nuestros </span>Anuncios</a> |
        <a href="//www.latimes.com/services/site/la-reprint-request-splash,0,6731163.htmlstory">© <script type="text/javascript">document.write(new Date().getFullYear())</script></a> |
    </div>
{% endblock %}
