<ul>
    <li>
        <a href="//www.latimes.com/local">Local</a>
    </li>
    <li>
        <a href="//www.latimes.com/california">California</a>
    </li>
    <li>
        <a href="//www.latimes.com/sports">Sports</a>
    </li>
    <li>
        <a href="//www.latimes.com/entertainment">Entertainment</a>
    </li>
    <li>
        <a href="//www.latimes.com/nation">Nation</a>
    </li>
    <li>
        <a href="//www.latimes.com/world">World</a>
    </li>
    <li>
        <a href="//www.latimes.com/business">Business</a>
    </li>
    <li>
        <a href="//www.latimes.com/opinion">Opinion</a>
    </li>
    <li>
        <a href="//www.latimes.com/style">Lifestyle</a>
    </li>
    <li>
        <a href="//www.latimes.com/travel">Travel</a>
    </li>
</ul>
