{% extends "ngux-tophat/base.html" %}

{% block title %}Hoy Los Angeles{% endblock %}

{% block nav %}
<nav title="Navigation">
    {% include "ngux-tophat/nav/hoy.html" %}
</nav>
{% endblock %}

{% block footer %}
<footer title="Footer">
    {% include "ngux-tophat/footer/hoy.html" %}
</footer>
{% endblock %}
