<div id="footer-container">
    <div id="footer">
        {% block content %}
            {% block footer-links %}
                <div id="tos">
                    <a href="//www.tronc.com/central-terms-of-service/">Terms of Service</a> |
                    <a href="//www.tronc.com/privacy-policy/">Privacy<span class="hidden-phone"> Policy</span></a> |
                    <a href="//www.latimes.com/lat-about-our-ads,0,3875412.htmlstory"><span class="hidden-phone">About Our </span>Ads</a> |
                    <a href="//www.latimes.com/services/site/la-reprint-request-splash,0,6731163.htmlstory">&copy; <script type="text/javascript">document.write(new Date().getFullYear())</script></a> |
                    <a href="//www.latimes.com/about/"><span class="hidden-phone">About This Site</span></a>
                </div>
            {% endblock %}
        {% endblock %}
    </div>
</div>
